Document<T> class
- Implemented types
-
- Implementers
Methods
-
create(T data, {bool broadcast = true, bool persist = true})
→ DocumentSnapshot<T>
-
-
createOrUpdate(T data, {bool? broadcast, bool persist = true})
→ DocumentSnapshot<T>
-
-
delete()
→ void
-
-
dependencies()
→ Set<Document>?
-
-
dependents()
→ Set<Document>?
-
-
exists()
→ bool
-
-
get()
→ DocumentSnapshot<T>?
-
-
getSerialized()
→ dynamic
-
Returns the serialized document data.
-
isPersistenceEnabled()
→ bool
-
-
modify(ModifyFn<T> modifyFn, {bool? broadcast, bool persist = true})
→ DocumentSnapshot<T>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
observe({bool multicast = false})
→ ObservableDocument<T>
-
-
rebroadcast()
→ void
-
Schedules a document to be rebroadcasted, updating all listeners that are subscribed to that document.
-
rebuildDependencies()
→ void
-
Rebuild the document's dependencies with the dependenciesBuilder.
-
stream()
→ Stream<DocumentSnapshot<T>?>
-
-
streamChanges()
→ Stream<DocumentChangeSnapshot<T>>
-
-
subcollection<S>(String name, {FromJson<S>? fromJson, ToJson<S>? toJson, PersistorSettings? persistorSettings, DependenciesBuilder<S>? dependenciesBuilder})
→ Collection<S>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(T data, {bool? broadcast, bool persist = true})
→ DocumentSnapshot<T>
-