Query<T> class

Inheritance
Implementers

Constructors

Query(Collection<T> collection, {List<FilterFn<T>> filters = const [], SortFn<T>? sort})

Properties

collection → Collection<T>
final
filters → List<FilterFn<T>>
final
hashCode → int
The hash code for this object.
no setterinherited
path → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sort → SortFn<T>?
final

Methods

get() → List<DocumentSnapshot<T>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
observe({bool multicast = false}) → ObservableQuery<T>
sortBy(SortFn<T> sort) → Query<T>
stream() → Stream<List<DocumentSnapshot<T>>>
streamChanges() → Stream<List<DocumentChangeSnapshot<T>>>
toQuery() → Query<T>
override
toString() → String
A string representation of this object.
inherited
where(FilterFn<T> filter) → Query<T>

Operators

operator ==(Object other) → bool
The equality operator.
inherited