DataStore class

Constructors

DataStore(DataStoreConfig config)

Properties

config → DataStoreConfig
final
hashCode → int
The hash code for this object.
no setterinherited
isDirty ↔ bool
getter/setter pair
isEmpty → bool
no setter
isHydrated ↔ bool
getter/setter pair
logger → Logger
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete() → Future<void>
extract([String path = '']) → Map<String, dynamic>
Returns a map of the subset of documents in the store under the given path. Data for the given path can exist in two different places:
hydrate() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
persist() → Future<void>
sync() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited