DataStoreConfig class abstract

Implementers

Constructors

DataStoreConfig(String name, {required Future<ValueStore<ValueStore>?> hydrate(), required Future<void> persist(ValueStore<ValueStore>), required Future<void> delete(), required bool encrypted, required DataStoreEncrypter encrypter, required Logger logger})

Properties

delete → Future<void> Function()
final
hashCode → int
The hash code for this object.
no setterinherited
hydrate → Future<ValueStore<ValueStore>?> Function()
final
logger → Logger
final
name → String
final
persist → Future<void> Function(ValueStore<ValueStore>)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited