DataStoreManager class

Constructors

DataStoreManager({required Duration persistenceThrottle, required void onSync()?, required PersistorSettings settings, required DataStoreFactory factory, required DataStoreResolverConfig resolverConfig, required DataStoreEncrypter encrypter, required Future<void> clearAll(), required Future<List<String>> getAll(), required Logger logger})

Properties

encrypter → DataStoreEncrypter
final
factory → DataStoreFactory
final
hashCode → int
The hash code for this object.
no setterinherited
index ↔ Map<String, DualDataStore>
The index of DualDataStore objects by store name.
getter/setter pair
logger → Logger
final
onSync → void Function()?
final
persistenceThrottle → Duration
The duration by which to throttle persistence changes to the file system.
final
resolver ↔ DataStoreResolver
The resolver that contains a mapping of documents to the file data store in which the document is currently stored.
getter/setter pair
resolverConfig → DataStoreResolverConfig
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → PersistorSettings
The global persistor settings.
final

Methods

clear(List<String> paths) → Future<void>
clearAll() → Future<void>
hydrate(List<String>? paths) → Future<Map<String, dynamic>>
Hydrates the given paths and returns a map of document paths to their serialized data.
init() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
persist(PersistPayload payload) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited