DataStoreResolver class

The data store resolver is persisted alongside the existing data stores and is used to maintain the resolution of documents to their associated data store.

Properties

config → DataStoreResolverConfig
final
hashCode → int
The hash code for this object.
no setterinherited
isDirty ↔ bool
getter/setter pair
isEmpty → bool
no setter
isHydrated ↔ bool
getter/setter pair
logger ↔ Logger
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete() → Future<void>
deletePath(String path, {bool recursive = true}) → void
extractParentPath(String path) → Map<String, String>
extractValues(String path) → Set<String>
get(String path) → String?
getNearest(String path) → (String, String)?
hydrate() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
persist() → Future<void>
sync() → Future<void>
toString() → String
A string representation of this object.
inherited
writePath(String path, dynamic value) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

name → const String