DataStoreResolverConfig class

Implementers

Constructors

DataStoreResolverConfig({required Future<ValueRefStore<String>?> hydrate(), required Future<void> persist(ValueRefStore<String>), required Future<void> delete(), required Logger logger})

Properties

delete → Future<void> Function()
final
hashCode → int
The hash code for this object.
no setterinherited
hydrate → Future<ValueRefStore<String>?> Function()
final
logger → Logger
final
persist → Future<void> Function(ValueRefStore<String>)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited