PersistenceDocument<T> class

Defines the minimum document interface necessary for document storage in the persistence layer.

Constructors

PersistenceDocument({required String path, required dynamic data, required bool encrypted})

Properties

data → dynamic
The serialized document data.
final
encrypted → bool
Whether encryption is enabled for this document.
final
hashCode → int
The hash code for this object.
no setterinherited
path → String
The path of the document in the store.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited