HydrateMessageRequest class

Inheritance

Constructors

HydrateMessageRequest([List<String>? paths])

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
paths → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

error(String text) → ErrorMessageResponse
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
success(Map<String, dynamic> data) → HydrateMessageResponse
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited