HydrateMessageResponse class

Inheritance

Constructors

HydrateMessageResponse({required String id, required Map<String, dynamic> data})

Properties

data → Map<String, dynamic>
A map of document paths to the document's hydrated data.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited