InitMessageRequest class

Inheritance

Constructors

InitMessageRequest({required SendPort sendPort})

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendPort → SendPort
final

Methods

error(String text) → ErrorMessageResponse
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
success(SendPort sendPort) → InitMessageResponse
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited