PersistorWorker<T extends PersistorWorkerConfig> class abstract

The background worker.

Implementers

Constructors

PersistorWorker(T config)

Properties

config → T
final
hashCode → int
The hash code for this object.
no setterinherited
logger → Logger
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear(List<String> collections) → Future<void>
clearAll() → Future<void>
hydrate(List<String>? paths) → Future<Map<String, dynamic>>
init() → Future<void>
Worker request handlers
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMessage(dynamic message) → Future<void>
onSync() → void
persist(PersistPayload payload) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited