PersistorWorkerConfig class

Implementers

Constructors

PersistorWorkerConfig({required PersistorSettings settings, required DataStoreEncrypter encrypter, required Duration persistenceThrottle})

Properties

encrypter → DataStoreEncrypter
final
hashCode → int
The hash code for this object.
no setterinherited
persistenceThrottle → Duration
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → PersistorSettings
final
token → RootIsolateToken
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited